@@ -16,7 +16,7 @@ use HTML::TokeParser;
 use Data::Dumper;
 use URI::Escape;
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 Construct Tk::Widget 'HyperText';
 
@@ -2041,6 +2041,9 @@ L<Tk::ROText> and L<Tk::Text>.
 
 =head1 CHANGES
 
+  0.09 Nov 11, 2013
+  - Reformatted as per CPAN::Changes::Spec -neilbowers
+
   0.08 Nov  1, 2013
   - Use hex() instead of eval() to convert hex strings into numbers.
   - Set default values for body colors.
